from django.shortcuts import render
from .models import EditorGuide


def index(request):
    # There should only ever be one instance of the guide
    content = EditorGuide.objects.all().first()

    # Send a boolean to populate a menu if there are more than
    # one 'heading' block type.
    nav = False
    if content:
        if len([i.block_type for i in content.sections if i.block_type=='heading']) > 1:
            nav = True

    return render(request, 'wagtail_guide/base.html', {
        'content': content,
        'nav': nav
    })


from django.conf.urls import url
from django.urls import reverse
from django.utils.translation import ugettext_lazy as _

from wagtail.admin.menu import MenuItem
from wagtail.core import hooks

from . import views


@hooks.register('register_admin_urls')
def register_admin_urls():
    return [
        url(r'^editorguide/$', views.index, name='wagtaileditorguide'),
    ]


@hooks.register('register_admin_menu_item')
def register_editor_guide_menu_item():
    return MenuItem(
        _('Editor guide'),
        reverse('wagtaileditorguide'),
        classnames='icon icon-help',
        order=1000
    )


from django.test import TestCase
from django.urls import reverse
from django.contrib.auth import get_user_model
from django.contrib.auth.models import Group

from wagtail.core.models import Page
from wagtail.tests.utils import WagtailTestUtils
from ..models import EditorGuide
from wagtail.tests.utils.form_data import (
    streamfield, nested_form_data, inline_formset)

class EditorGuideTest(TestCase, WagtailTestUtils):

    def setUp(self):
        super().setUp()
        self.login()
        User = get_user_model()
        editors_group = Group.objects.get(name='Editors')

        self.editor = User.objects.create_user(username='testuser', password='pass')
        self.editor.groups.add(editors_group)

    def test_admin(self):
        response = self.client.get(reverse('wagtailadmin_home'))
        self.assertEqual(response.status_code, 200)

    def test_guide_view_links(self):
        response = self.client.get(reverse('wagtailadmin_home'))
        self.assertContains(response, '<a href="/admin/editorguide/" class="icon icon-help">Editor guide</a>', html=True)

    def test_guide_edit_links(self):
        response = self.client.get(reverse('wagtailadmin_home'))
        self.assertContains(response, '<a href="/admin/settings/wagtail_guide/editorguide/" class="icon icon-help">Manage Editor Guide</a>', html=True)

    def test_editor_view(self):
        response = self.client.get(reverse('wagtaileditorguide'))
        self.assertEqual(response.status_code, 200)

    def test_editor_view_null_message(self):
        # Check we see the no create message if no guide is added
        response = self.client.get(reverse('wagtaileditorguide'))
        self.assertContains(response, '<p class="help-block help-warning">An editor guide has not been created yet. Add one in Settings > Editor guide</p>', html=True)

    def test_adding_a_guide(self):
        # Check we can see field data in the guide once added
        EditorGuide.objects.create(
            information_text='9999',
            sections = [
                ('heading', 'A Heading'),
                ('heading', 'Another heading'),
            ],
            site_id=1
        )
        response = self.client.get(reverse('wagtaileditorguide'))
        self.assertContains(response, 'A Heading')

    def test_permissions(self):
        # Unless the manage permission guide is added to the editor group,
        # An editor shouldn't be able to see the managle link in settings > manage guide
        self.client.logout()
        self.client.login(username='testuser', password='pass')
        response = self.client.get(reverse('wagtailadmin_home'))
        self.assertNotContains(response, '<a href="/admin/settings/wagtail_guide/editorguide/" class="icon icon-help">Manage Editor Guide</a>', html=True)


from django.db import models

from modelcluster.models import ClusterableModel
from wagtail.admin.edit_handlers import StreamFieldPanel, FieldPanel
from wagtail.contrib.settings.models import BaseSetting, register_setting
from wagtail.core.fields import StreamField
from wagtail.core import blocks
from wagtail.embeds.blocks import EmbedBlock
from wagtail.images.blocks import ImageChooserBlock


class ImageBlock(blocks.StructBlock):
    image = ImageChooserBlock()
    caption = blocks.CharBlock(required=False)

    class Meta:
        icon = "image"
        template = "wagtail_guide/streamfield/blocks/image_block.html"


class QuoteBlock(blocks.StructBlock):
    quote = blocks.CharBlock(classname="title")
    attribution = blocks.CharBlock(required=False)

    class Meta:
        icon = "openquote"
        template = "wagtail_guide/streamfield/blocks/quote_block.html"


class PullQuoteBlock(blocks.StructBlock):
    pull_quote = blocks.CharBlock(classname="title")

    class Meta:
        icon = "openquote"
        template = "wagtail_guide/streamfield/blocks/pull_quote_block.html"


class IframeBlock(blocks.StructBlock):
    title = blocks.CharBlock(required=False)
    source = blocks.URLBlock()

    class Meta:
        icon = "code"
        template = "wagtail_guide/streamfield/blocks/iframe_block.html"


class EmbedTitleBlock(blocks.StructBlock):
    title = blocks.CharBlock(required=False)
    embed = EmbedBlock()

    class Meta:
        icon = "media"
        template = 'wagtail_guide/streamfield/blocks/embed_block.html'


class VideoBlock(blocks.StructBlock):
    video = EmbedBlock(required=False, label='Video URL')

    class Meta:
        icon = "media"
        template = 'wagtail_guide/streamfield/blocks/video_block.html'
        label = "Video"


class GuideBlock(blocks.StreamBlock):
    heading = blocks.CharBlock(
        classname='full title', icon='title',
        template='wagtail_guide/streamfield/blocks/heading_block.html'
    )

    paragraph = blocks.RichTextBlock(features=[
        'h2', 'h3', 'h4', 'h5', 'h6', 'bold', 'italic', 'link', 'ul', 'ol', 'hr'])
    image = ImageBlock()
    quote = QuoteBlock()
    pull_quote = PullQuoteBlock()
    embed = EmbedTitleBlock()
    video = VideoBlock()

    class Meta:
        template = "wagtail_guide/streamfield/stream_block.html"


@register_setting(icon="help")
class EditorGuide(BaseSetting, ClusterableModel):
    information_text = models.TextField(
        blank=True, help_text='Add a leading information paragraph explaining the guide')
    sections = StreamField(GuideBlock(required=False), blank=True)

    panels = [
        FieldPanel('information_text'),
        StreamFieldPanel('sections')
    ]

    class Meta:
        verbose_name = 'Manage Editor Guide'



from django.contrib import admin
from django.urls import include, path

from wagtail.admin import urls as wagtailadmin_urls
from wagtail.core import urls as wagtail_urls
from wagtail.documents import urls as wagtaildocs_urls

private_urlpatterns = [
    path('django-admin/', admin.site.urls),
    path('admin/', include(wagtailadmin_urls)),
    path('documents/', include(wagtaildocs_urls)),
]

# Public URLs that are meant to be cached.
urlpatterns = []

urlpatterns = private_urlpatterns + urlpatterns + [
    # Add Wagtail URLs at the end.
    # Wagtail cache-control is set on the page models's serve methods.
    path('', include(wagtail_urls)),
]




#!/usr/bin/env python
"""
Installs the Wagtail Guide plugin.
"""

from setuptools import setup, find_packages
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(name='wagtail_guide',
      version='1.0.1',
      description='Adds functionality to add and edit a CMS guide page for editors.',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='https://github.com/kevinhowbrook/wagtail_guide',
      author='Kevin Howbrook - Torchbox',
      author_email='kevin.howbrook@torchbox.com',
      license='MIT',
      packages=find_packages(exclude=['tests*']),
      include_package_data=True,
      install_requires=[
          'wagtail>=2.4',
      ])



# Generated by Django 2.1.8 on 2019-05-18 11:38

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.embeds.blocks
import wagtail.images.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0041_group_collection_permissions_verbose_name_plural'),
    ]

    operations = [
        migrations.CreateModel(
            name='EditorGuide',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('information_text', models.TextField(blank=True, help_text='Add a leading information paragraph explaining the guide')),
                ('sections', wagtail.core.fields.StreamField([('heading', wagtail.core.blocks.CharBlock(classname='full title', icon='title', template='wagtail_guide/streamfield/blocks/heading_block.html')), ('paragraph', wagtail.core.blocks.RichTextBlock(features=['h2', 'h3', 'h4', 'h5', 'h6', 'bold', 'italic', 'link', 'ul', 'ol', 'hr'])), ('image', wagtail.core.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('caption', wagtail.core.blocks.CharBlock(required=False))])), ('quote', wagtail.core.blocks.StructBlock([('quote', wagtail.core.blocks.CharBlock(classname='title')), ('attribution', wagtail.core.blocks.CharBlock(required=False))])), ('pull_quote', wagtail.core.blocks.StructBlock([('pull_quote', wagtail.core.blocks.CharBlock(classname='title'))])), ('embed', wagtail.core.blocks.StructBlock([('title', wagtail.core.blocks.CharBlock(required=False)), ('embed', wagtail.embeds.blocks.EmbedBlock())])), ('video', wagtail.core.blocks.StructBlock([('video', wagtail.embeds.blocks.EmbedBlock(label='Video URL', required=False))]))], blank=True)),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'Manage Editor Guide',
            },
        ),
    ]
